==> material-ui-shell-1.1.8.tgz: package/es/components/QuestionDialog/QuestionDialog.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import Button from '@material-ui/core/Button';
import Dialog from '@material-ui/core/Dialog';
import DialogActions from '@material-ui/core/DialogActions';
import DialogContent from '@material-ui/core/DialogContent';
import DialogContentText from '@material-ui/core/DialogContentText';
import DialogTitle from '@material-ui/core/DialogTitle';
import React, { useContext } from 'react';
import Slide from '@material-ui/core/Slide';
import useMediaQuery from '@material-ui/core/useMediaQuery';
import { useIntl } from 'react-intl';
import { useSimpleValues } from 'base-shell/lib/providers/SimpleValues';
import { useTheme } from '@material-ui/core/styles';
var Transition = React.forwardRef(function (props, ref) {
  return /*#__PURE__*/React.createElement(Slide, _extends({
    direction: "up"
  }, props, {
    ref: ref
  }));
});

var QuestionDialog = function QuestionDialog(_ref) {
  var _ref$isProcessing = _ref.isProcessing,
      isProcessing = _ref$isProcessing === void 0 ? false : _ref$isProcessing,
      _ref$isOpen = _ref.isOpen,
      isOpen = _ref$isOpen === void 0 ? false : _ref$isOpen,
      _ref$id = _ref.id,
      id = _ref$id === void 0 ? '' : _ref$id,
      _ref$message = _ref.message,
      message = _ref$message === void 0 ? '' : _ref$message,
      _ref$title = _ref.title,
      title = _ref$title === void 0 ? '' : _ref$title,
      _ref$action = _ref.action,
      action = _ref$action === void 0 ? '' : _ref$action,
      _ref$handleAction = _ref.handleAction,
      handleAction = _ref$handleAction === void 0 ? function () {} : _ref$handleAction,
      _ref$handleClose = _ref.handleClose,
      handleClose = _ref$handleClose === void 0 ? function () {} : _ref$handleClose;
  var intl = useIntl();
  var theme = useTheme();

  var _useSimpleValues = useSimpleValues(),
      getValue = _useSimpleValues.getValue,
      clearValue = _useSimpleValues.clearValue;

  var fullScreen = useMediaQuery(theme.breakpoints.down('sm'));
  var isDialogOpen = getValue(id, false);
  return /*#__PURE__*/React.createElement(Dialog, {
    fullScreen: fullScreen,
    open: isOpen,
    onClose: handleClose,
    TransitionComponent: Transition,
    "aria-labelledby": "alert-dialog-title",
    "aria-describedby": "alert-dialog-description"
  }, /*#__PURE__*/React.createElement(DialogTitle, {
    id: "alert-dialog-title"
  }, title), /*#__PURE__*/React.createElement(DialogContent, null, /*#__PURE__*/React.createElement(DialogContentText, {
    id: "alert-dialog-description"
  }, message)), /*#__PURE__*/React.createElement(DialogActions, null, /*#__PURE__*/React.createElement(Button, {
    onClick: handleClose,
    color: "primary"
  }, intl.formatMessage({
    id: 'cancel',
    defaultMessage: 'Cancel'
  })), /*#__PURE__*/React.createElement(Button, {
    disabled: isProcessing,
    onClick: function onClick() {
      handleAction(handleClose);
    },
    color: "secondary"
  }, action)));
};

export default QuestionDialog;

==> material-ui-shell-1.1.12.tgz: package/es/components/QuestionDialog/QuestionDialog.js <==
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import Button from '@material-ui/core/Button';
import Dialog from '@material-ui/core/Dialog';
import DialogActions from '@material-ui/core/DialogActions';
import DialogContent from '@material-ui/core/DialogContent';
import DialogContentText from '@material-ui/core/DialogContentText';
import DialogTitle from '@material-ui/core/DialogTitle';
import React, { useContext } from 'react';
import Slide from '@material-ui/core/Slide';
import useMediaQuery from '@material-ui/core/useMediaQuery';
import { useIntl } from 'react-intl';
import { useTheme } from '@material-ui/core/styles';
var Transition = React.forwardRef(function (props, ref) {
  return /*#__PURE__*/React.createElement(Slide, _extends({
    direction: "up"
  }, props, {
    ref: ref
  }));
});

var QuestionDialog = function QuestionDialog(_ref) {
  var _ref$isProcessing = _ref.isProcessing,
      isProcessing = _ref$isProcessing === void 0 ? false : _ref$isProcessing,
      _ref$isOpen = _ref.isOpen,
      isOpen = _ref$isOpen === void 0 ? false : _ref$isOpen,
      _ref$id = _ref.id,
      id = _ref$id === void 0 ? '' : _ref$id,
      _ref$message = _ref.message,
      message = _ref$message === void 0 ? '' : _ref$message,
      _ref$title = _ref.title,
      title = _ref$title === void 0 ? '' : _ref$title,
      _ref$action = _ref.action,
      action = _ref$action === void 0 ? '' : _ref$action,
      _ref$handleAction = _ref.handleAction,
      handleAction = _ref$handleAction === void 0 ? function () {} : _ref$handleAction,
      _ref$handleClose = _ref.handleClose,
      handleClose = _ref$handleClose === void 0 ? function () {} : _ref$handleClose,
      rest = _objectWithoutPropertiesLoose(_ref, ["isProcessing", "isOpen", "id", "message", "title", "action", "handleAction", "handleClose"]);

  var intl = useIntl();
  var theme = useTheme();
  var fullScreen = useMediaQuery(theme.breakpoints.down('sm'));
  return /*#__PURE__*/React.createElement(Dialog, _extends({
    fullScreen: fullScreen,
    open: isOpen,
    onClose: handleClose,
    TransitionComponent: Transition,
    "aria-labelledby": "alert-dialog-title",
    "aria-describedby": "alert-dialog-description"
  }, rest), /*#__PURE__*/React.createElement(DialogTitle, {
    id: "alert-dialog-title"
  }, title), /*#__PURE__*/React.createElement(DialogContent, null, /*#__PURE__*/React.createElement(DialogContentText, {
    id: "alert-dialog-description"
  }, message)), /*#__PURE__*/React.createElement(DialogActions, null, /*#__PURE__*/React.createElement(Button, {
    onClick: handleClose,
    color: "primary"
  }, intl.formatMessage({
    id: 'cancel',
    defaultMessage: 'Cancel'
  })), /*#__PURE__*/React.createElement(Button, {
    disabled: isProcessing,
    onClick: function onClick() {
      handleAction(handleClose);
    },
    color: "secondary"
  }, action)));
};

export default QuestionDialog;
